@@ -2,7 +2,7 @@ from dallinger.deployment import DebugDeployment, setup_experiment
 
 
 class DockerDebugDeployment(DebugDeployment):
-    """Run the experiment in a local docker-compose based environment."""
+    """Run the experiment in a local docker compose based environment."""
 
     DEPLOY_NAME = "Docker"
     WRAPPER_CLASS = None
