@@ -584,6 +584,9 @@ class MTurkService(object):
             )
         return True
 
+    def get_study(self, hit_id):
+        return self.mturk.get_hit(HITId=hit_id)["HIT"]
+
     def get_hit(self, hit_id):
         return self._translate_hit(self.mturk.get_hit(HITId=hit_id)["HIT"])
 
